==> openjdk-23_23.0.2+7.orig.tar.xz: openjdk-23-23.0.2+7/test/micro/org/openjdk/bench/vm/gc/systemgc/DifferentObjectSizesTreeMap.java <==
/*
 * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.bench.vm.gc.systemgc;

import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.BenchmarkMode;
import org.openjdk.jmh.annotations.Fork;
import org.openjdk.jmh.annotations.Level;
import org.openjdk.jmh.annotations.Mode;
import org.openjdk.jmh.annotations.OutputTimeUnit;
import org.openjdk.jmh.annotations.Scope;
import org.openjdk.jmh.annotations.Setup;
import org.openjdk.jmh.annotations.State;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

@BenchmarkMode(Mode.SingleShotTime)
@Fork(value=25, jvmArgsAppend={"-Xmx5g", "-Xms5g", "-Xmn3g", "-XX:+AlwaysPreTouch"})
@OutputTimeUnit(TimeUnit.MILLISECONDS)
@State(Scope.Benchmark)
public class DifferentObjectSizesTreeMap {

    /*
     * Test the System GC when 2/3 of the objects are live
     * and kept reachable through a TreeMap.
     *
     * The jvmArgs are provided to avoid GCs during object creation.
     */
    static TreeMap<Integer, byte[]> largeMap;

    @Setup(Level.Iteration)
    public void generateGarbage() {
        largeMap = GarbageGenerator.generateAndFillTreeMap(false);
        int numberOfObjects = largeMap.size();
        // Removing a third of the objects and keeping a good
        // distribution of sizes.
        for (int i = 0; i < numberOfObjects; i++) {
            if (i%3 == 0) {
                largeMap.remove(i);
            }
        }
    }

    @Benchmark
    public void gc() {
        System.gc();
    }
}

==> openjdk-25_25.0.2+10.orig.tar.xz: openjdk-25-25.0.2+10/test/micro/org/openjdk/bench/vm/gc/systemgc/DifferentObjectSizesTreeMap.java <==
/*
 * Copyright (c) 2017, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.openjdk.bench.vm.gc.systemgc;

import org.openjdk.jmh.annotations.Benchmark;
import org.openjdk.jmh.annotations.BenchmarkMode;
import org.openjdk.jmh.annotations.Fork;
import org.openjdk.jmh.annotations.Level;
import org.openjdk.jmh.annotations.Measurement;
import org.openjdk.jmh.annotations.Mode;
import org.openjdk.jmh.annotations.OutputTimeUnit;
import org.openjdk.jmh.annotations.Scope;
import org.openjdk.jmh.annotations.Setup;
import org.openjdk.jmh.annotations.State;
import org.openjdk.jmh.annotations.Warmup;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

@BenchmarkMode(Mode.SingleShotTime)
@Warmup(iterations = 5)
@Measurement(iterations = 5)
@Fork(value=25, jvmArgs={"-Xmx5g", "-Xms5g", "-Xmn3g", "-XX:+AlwaysPreTouch"})
@OutputTimeUnit(TimeUnit.MILLISECONDS)
@State(Scope.Benchmark)
public class DifferentObjectSizesTreeMap {

    /*
     * Test the System GC when 2/3 of the objects are live
     * and kept reachable through a TreeMap.
     *
     * The jvmArgs are provided to avoid GCs during object creation.
     */
    static TreeMap<Integer, byte[]> largeMap;

    @Setup(Level.Trial)
    public void preRun() {
        // Compact right now, kicking out all unrelated objects
        System.gc();
    }

    @Setup(Level.Iteration)
    public void generateGarbage() {
        largeMap = GarbageGenerator.generateAndFillTreeMap(false);
        int numberOfObjects = largeMap.size();
        // Removing a third of the objects and keeping a good
        // distribution of sizes.
        for (int i = 0; i < numberOfObjects; i++) {
            if (i%3 == 0) {
                largeMap.remove(i);
            }
        }
    }

    @Benchmark
    public void gc() {
        System.gc();
    }
}
